@@ -1,4 +1,4 @@
-from django.contrib.contenttypes.fields import GenericForeignKey
+from django.contrib.contenttypes.fields import GenericForeignKey, GenericRelation
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
 from django.db.models import Sum, CharField
@@ -57,7 +57,7 @@ class Drive(NetBoxModel):
         ordering = ['size']
 
     def __str__(self):
-        return f'{self.identifier} ({self.size}MB {self.cluster})'
+        return f'{self.identifier} ({self.size} MB {self.cluster})'
 
     def get_absolute_url(self):
         return reverse('plugins:netbox_storage:drive', kwargs={'pk': self.pk})
@@ -146,11 +146,12 @@ class LinuxDevice(NetBoxModel):
         ct_field='content_type',
         fk_field='object_id'
     )
+    drives = GenericRelation(Drive, related_query_name='linux_device_drives')
 
     clone_fields = ['device', 'type', 'size', 'content_type', 'object_id']
 
     def __str__(self):
-        return f'{self.device}'
+        return f'{self.device} ({self.type})'
 
     def get_absolute_url(self):
         return reverse('plugins:netbox_storage:linuxdevice', kwargs={'pk': self.pk})
